@@ -22,20 +22,18 @@ package org.kie.api.runtime;
 public class ClassObjectFilter
     implements
     ObjectFilter {
-    private Class clazz;
+    private Class<?> clazz;
 
-    /** 
+    /**
      * The Allowed Class type
      * @param clazz
      */
-    public ClassObjectFilter(Class clazz) {
+    public ClassObjectFilter(Class<?> clazz) {
         this.clazz = clazz;
     }
 
     /**
-     * Returns true if the Iterator accepts the given object according to its class.
-     * @param object
-     * @return
+     * @return true if the Iterator accepts the given object according to its class.
      */
     public boolean accept(Object object) {
         return this.clazz.isAssignableFrom( object.getClass() );
